@@ -377,10 +377,15 @@ def resolve_and_validate_document(
 
     document_loader.resolve_all(workflowobj, fileuri)
     processobj, metadata = document_loader.resolve_ref(uri)
-    if loadingContext.metadata:
-        metadata = loadingContext.metadata
     if not isinstance(processobj, (CommentedMap, CommentedSeq)):
         raise ValidationException("Workflow must be a CommentedMap or CommentedSeq.")
+
+    if not hasattr(processobj.lc, "filename"):
+        processobj.lc.filename = fileuri
+
+    if loadingContext.metadata:
+        metadata = loadingContext.metadata
+
     if not isinstance(metadata, CommentedMap):
         raise ValidationException(
             "metadata must be a CommentedMap, was %s" % type(metadata)
